package com.sunyard.security;

import java.security.cert.X509CRL;
import java.security.cert.X509Certificate;

public class Main {
    public static void main(String[] args) throws Exception {

        if ( args.length < 2 ) {
            System.out.println("用法: java -jar sm2-crl-checker-1.0-jar-with-dependencies <根证书路径> <CRL文件路径>");
            return;
        }

        String rootCertPath = args[0];
        String crlFilePath = args[1];


        System.out.println("根证书路径: " + rootCertPath);
        System.out.println("CRL文件路径: " + crlFilePath);
        System.out.println("开始验证CRL...");


        // 1. 读取根证书
        X509Certificate rootCert = CRLValidator.readRootCertificate(rootCertPath);

        // 2. 读取CRL文件
        X509CRL crl = CRLValidator.readCRLFile(crlFilePath);

        // 3. 验证CRL签名
        CRLValidator.verifyCRLSignature(rootCert, crl);

        // 4. 检查CRL是否有效（未过期）
        CRLValidator.checkCRLValidity(crl);

        // 5. 可选：打印CRL信息
        CRLValidator.printCRLInfo(crl);

        System.out.println("CRL验证结束！");
    }
}